==> gromacs_2018.1.orig.tar.gz: gromacs-2018.1/src/gromacs/utility/int64_to_int.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2015, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal\file
 * \brief
 * Low-level utility for converting 64 bit int to int (the
 * size of which is hardware dependent), printing
 * a warning if an overflow will occur.
 *
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_INT64_TO_INT_H
#define GMX_UTILITY_INT64_TO_INT_H

#include "gromacs/utility/futil.h"

/*! \brief Convert a gmx_int64_t value to int.
 *
 * \param[in] step The step number (or other int64)
 * \param[in] warn If warn!=NULL a warning message will be written
 *                 to stderr when step does not fit in an int,
 *                 the first line is:
 *                 "WARNING during %s:", where warn is printed in %s.
 * \return the truncated step number.
 */
int gmx_int64_to_int(gmx_int64_t step, const char *warn);

#endif

==> gromacs_2019.3.orig.tar.gz: gromacs-2019.3/src/gromacs/utility/int64_to_int.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2015,2018, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal\file
 * \brief
 * Low-level utility for converting 64 bit int to int (the
 * size of which is hardware dependent), printing
 * a warning if an overflow will occur.
 *
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_INT64_TO_INT_H
#define GMX_UTILITY_INT64_TO_INT_H

#include "gromacs/utility/futil.h"

/*! \brief Convert a int64_t value to int.
 *
 * \param[in] step The step number (or other int64)
 * \param[in] warn If warn!=NULL a warning message will be written
 *                 to stderr when step does not fit in an int,
 *                 the first line is:
 *                 "WARNING during %s:", where warn is printed in %s.
 * \return the truncated step number.
 */
int int64_to_int(int64_t step, const char *warn);

#endif
